# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRepoRuleBranchResult',
    'AwaitableGetRepoRuleBranchResult',
    'get_repo_rule_branch',
    'get_repo_rule_branch_output',
]

@pulumi.output_type
class GetRepoRuleBranchResult:
    """
    A collection of values returned by getRepoRuleBranch.
    """
    def __init__(__self__, bypasses=None, created=None, created_by=None, description=None, id=None, identifier=None, org_id=None, patterns=None, policies=None, project_id=None, repo_identifier=None, state=None, updated=None, updated_by=None):
        if bypasses and not isinstance(bypasses, list):
            raise TypeError("Expected argument 'bypasses' to be a list")
        pulumi.set(__self__, "bypasses", bypasses)
        if created and not isinstance(created, int):
            raise TypeError("Expected argument 'created' to be a int")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, int):
            raise TypeError("Expected argument 'created_by' to be a int")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if patterns and not isinstance(patterns, list):
            raise TypeError("Expected argument 'patterns' to be a list")
        pulumi.set(__self__, "patterns", patterns)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if repo_identifier and not isinstance(repo_identifier, str):
            raise TypeError("Expected argument 'repo_identifier' to be a str")
        pulumi.set(__self__, "repo_identifier", repo_identifier)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if updated and not isinstance(updated, int):
            raise TypeError("Expected argument 'updated' to be a int")
        pulumi.set(__self__, "updated", updated)
        if updated_by and not isinstance(updated_by, int):
            raise TypeError("Expected argument 'updated_by' to be a int")
        pulumi.set(__self__, "updated_by", updated_by)

    @_builtins.property
    @pulumi.getter
    def bypasses(self) -> Sequence['outputs.GetRepoRuleBranchBypassResult']:
        """
        List of users who can bypass this rule.
        """
        return pulumi.get(self, "bypasses")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.int:
        """
        Timestamp when the rule was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.int:
        """
        ID of the user who created the rule.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Description of the rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the rule.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def patterns(self) -> Optional[Sequence['outputs.GetRepoRuleBranchPatternResult']]:
        """
        Pattern of branch to which rule will apply.
        """
        return pulumi.get(self, "patterns")

    @_builtins.property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetRepoRuleBranchPolicyResult']:
        """
        Policies to be applied for this rule.
        """
        return pulumi.get(self, "policies")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="repoIdentifier")
    def repo_identifier(self) -> _builtins.str:
        """
        Repo identifier of the repository.
        """
        return pulumi.get(self, "repo_identifier")

    @_builtins.property
    @pulumi.getter
    def state(self) -> _builtins.str:
        """
        State of the rule (active, disable, monitor).
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def updated(self) -> _builtins.int:
        """
        Timestamp when the rule was updated.
        """
        return pulumi.get(self, "updated")

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> _builtins.int:
        """
        ID of the user who updated the rule.
        """
        return pulumi.get(self, "updated_by")


class AwaitableGetRepoRuleBranchResult(GetRepoRuleBranchResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepoRuleBranchResult(
            bypasses=self.bypasses,
            created=self.created,
            created_by=self.created_by,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            org_id=self.org_id,
            patterns=self.patterns,
            policies=self.policies,
            project_id=self.project_id,
            repo_identifier=self.repo_identifier,
            state=self.state,
            updated=self.updated,
            updated_by=self.updated_by)


def get_repo_rule_branch(bypasses: Optional[Sequence[Union['GetRepoRuleBranchBypassArgs', 'GetRepoRuleBranchBypassArgsDict']]] = None,
                         description: Optional[_builtins.str] = None,
                         identifier: Optional[_builtins.str] = None,
                         org_id: Optional[_builtins.str] = None,
                         patterns: Optional[Sequence[Union['GetRepoRuleBranchPatternArgs', 'GetRepoRuleBranchPatternArgsDict']]] = None,
                         policies: Optional[Sequence[Union['GetRepoRuleBranchPolicyArgs', 'GetRepoRuleBranchPolicyArgsDict']]] = None,
                         project_id: Optional[_builtins.str] = None,
                         repo_identifier: Optional[_builtins.str] = None,
                         state: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepoRuleBranchResult:
    """
    Data source for retrieving a Harness repo branch rule.


    :param Sequence[Union['GetRepoRuleBranchBypassArgs', 'GetRepoRuleBranchBypassArgsDict']] bypasses: List of users who can bypass this rule.
    :param _builtins.str description: Description of the rule.
    :param _builtins.str identifier: Identifier of the rule.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param Sequence[Union['GetRepoRuleBranchPatternArgs', 'GetRepoRuleBranchPatternArgsDict']] patterns: Pattern of branch to which rule will apply.
    :param Sequence[Union['GetRepoRuleBranchPolicyArgs', 'GetRepoRuleBranchPolicyArgsDict']] policies: Policies to be applied for this rule.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str repo_identifier: Repo identifier of the repository.
    :param _builtins.str state: State of the rule (active, disable, monitor).
    """
    __args__ = dict()
    __args__['bypasses'] = bypasses
    __args__['description'] = description
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['patterns'] = patterns
    __args__['policies'] = policies
    __args__['projectId'] = project_id
    __args__['repoIdentifier'] = repo_identifier
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getRepoRuleBranch:getRepoRuleBranch', __args__, opts=opts, typ=GetRepoRuleBranchResult).value

    return AwaitableGetRepoRuleBranchResult(
        bypasses=pulumi.get(__ret__, 'bypasses'),
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        org_id=pulumi.get(__ret__, 'org_id'),
        patterns=pulumi.get(__ret__, 'patterns'),
        policies=pulumi.get(__ret__, 'policies'),
        project_id=pulumi.get(__ret__, 'project_id'),
        repo_identifier=pulumi.get(__ret__, 'repo_identifier'),
        state=pulumi.get(__ret__, 'state'),
        updated=pulumi.get(__ret__, 'updated'),
        updated_by=pulumi.get(__ret__, 'updated_by'))
def get_repo_rule_branch_output(bypasses: Optional[pulumi.Input[Sequence[Union['GetRepoRuleBranchBypassArgs', 'GetRepoRuleBranchBypassArgsDict']]]] = None,
                                description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                patterns: Optional[pulumi.Input[Optional[Sequence[Union['GetRepoRuleBranchPatternArgs', 'GetRepoRuleBranchPatternArgsDict']]]]] = None,
                                policies: Optional[pulumi.Input[Sequence[Union['GetRepoRuleBranchPolicyArgs', 'GetRepoRuleBranchPolicyArgsDict']]]] = None,
                                project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                state: Optional[pulumi.Input[_builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRepoRuleBranchResult]:
    """
    Data source for retrieving a Harness repo branch rule.


    :param Sequence[Union['GetRepoRuleBranchBypassArgs', 'GetRepoRuleBranchBypassArgsDict']] bypasses: List of users who can bypass this rule.
    :param _builtins.str description: Description of the rule.
    :param _builtins.str identifier: Identifier of the rule.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param Sequence[Union['GetRepoRuleBranchPatternArgs', 'GetRepoRuleBranchPatternArgsDict']] patterns: Pattern of branch to which rule will apply.
    :param Sequence[Union['GetRepoRuleBranchPolicyArgs', 'GetRepoRuleBranchPolicyArgsDict']] policies: Policies to be applied for this rule.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str repo_identifier: Repo identifier of the repository.
    :param _builtins.str state: State of the rule (active, disable, monitor).
    """
    __args__ = dict()
    __args__['bypasses'] = bypasses
    __args__['description'] = description
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['patterns'] = patterns
    __args__['policies'] = policies
    __args__['projectId'] = project_id
    __args__['repoIdentifier'] = repo_identifier
    __args__['state'] = state
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getRepoRuleBranch:getRepoRuleBranch', __args__, opts=opts, typ=GetRepoRuleBranchResult)
    return __ret__.apply(lambda __response__: GetRepoRuleBranchResult(
        bypasses=pulumi.get(__response__, 'bypasses'),
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        org_id=pulumi.get(__response__, 'org_id'),
        patterns=pulumi.get(__response__, 'patterns'),
        policies=pulumi.get(__response__, 'policies'),
        project_id=pulumi.get(__response__, 'project_id'),
        repo_identifier=pulumi.get(__response__, 'repo_identifier'),
        state=pulumi.get(__response__, 'state'),
        updated=pulumi.get(__response__, 'updated'),
        updated_by=pulumi.get(__response__, 'updated_by')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GitOpsApplicationsArgs', 'GitOpsApplications']

@pulumi.input_type
class GitOpsApplicationsArgs:
    def __init__(__self__, *,
                 agent_id: pulumi.Input[_builtins.str],
                 applications: pulumi.Input[Sequence[pulumi.Input['GitOpsApplicationsApplicationArgs']]],
                 cluster_id: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options_remove_existing_finalizers: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 request_cascade: Optional[pulumi.Input[_builtins.bool]] = None,
                 request_propagation_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_repo_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 validate: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a GitOpsApplications resource.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps application.
        :param pulumi.Input[Sequence[pulumi.Input['GitOpsApplicationsApplicationArgs']]] applications: Definition of the GitOps application resource.
        :param pulumi.Input[_builtins.str] cluster_id: Cluster identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] kind: Kind of the GitOps application.
        :param pulumi.Input[_builtins.str] name: Name of the GitOps application.
        :param pulumi.Input[_builtins.bool] options_remove_existing_finalizers: Options to remove existing finalizers to delete the GitOps application.
        :param pulumi.Input[_builtins.str] project: The ArgoCD project name corresponding to this GitOps application. An empty string means that the GitOps application belongs to the default project created by Harness.
        :param pulumi.Input[_builtins.str] repo_id: Repository identifier of the GitOps application. When using skipRepoValidation, this field is not required.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] repo_ids: List of repository identifiers of the GitOps for Multi-Source application. Not required if skipRepoValidation is set to true.
        :param pulumi.Input[_builtins.bool] request_cascade: Request cascade to delete the GitOps application.
        :param pulumi.Input[_builtins.str] request_propagation_policy: Request propagation policy to delete the GitOps application.
        :param pulumi.Input[_builtins.bool] skip_repo_validation: Indicates if the GitOps application should skip validate repository definition exists.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps application should be updated if existing and inserted if not.
        :param pulumi.Input[_builtins.bool] validate: Indicates if the GitOps application yaml has to be validated.
        """
        pulumi.set(__self__, "agent_id", agent_id)
        pulumi.set(__self__, "applications", applications)
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        if account_id is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: This field is deprecated and will be removed in a future release.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if identifier is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""identifier is deprecated: This field is deprecated and will be removed in a future release.""")
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if options_remove_existing_finalizers is not None:
            pulumi.set(__self__, "options_remove_existing_finalizers", options_remove_existing_finalizers)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if repo_id is not None:
            pulumi.set(__self__, "repo_id", repo_id)
        if repo_ids is not None:
            pulumi.set(__self__, "repo_ids", repo_ids)
        if request_cascade is not None:
            pulumi.set(__self__, "request_cascade", request_cascade)
        if request_propagation_policy is not None:
            pulumi.set(__self__, "request_propagation_policy", request_propagation_policy)
        if skip_repo_validation is not None:
            pulumi.set(__self__, "skip_repo_validation", skip_repo_validation)
        if upsert is not None:
            pulumi.set(__self__, "upsert", upsert)
        if validate is not None:
            pulumi.set(__self__, "validate", validate)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Input[_builtins.str]:
        """
        Agent identifier of the GitOps application.
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter
    def applications(self) -> pulumi.Input[Sequence[pulumi.Input['GitOpsApplicationsApplicationArgs']]]:
        """
        Definition of the GitOps application resource.
        """
        return pulumi.get(self, "applications")

    @applications.setter
    def applications(self, value: pulumi.Input[Sequence[pulumi.Input['GitOpsApplicationsApplicationArgs']]]):
        pulumi.set(self, "applications", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[_builtins.str]:
        """
        Cluster identifier of the GitOps application.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Organization identifier of the GitOps application.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Project identifier of the GitOps application.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account identifier of the GitOps application.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the GitOps application.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Kind of the GitOps application.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kind", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the GitOps application.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="optionsRemoveExistingFinalizers")
    def options_remove_existing_finalizers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Options to remove existing finalizers to delete the GitOps application.
        """
        return pulumi.get(self, "options_remove_existing_finalizers")

    @options_remove_existing_finalizers.setter
    def options_remove_existing_finalizers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "options_remove_existing_finalizers", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ArgoCD project name corresponding to this GitOps application. An empty string means that the GitOps application belongs to the default project created by Harness.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="repoId")
    def repo_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository identifier of the GitOps application. When using skipRepoValidation, this field is not required.
        """
        return pulumi.get(self, "repo_id")

    @repo_id.setter
    def repo_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repo_id", value)

    @_builtins.property
    @pulumi.getter(name="repoIds")
    def repo_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of repository identifiers of the GitOps for Multi-Source application. Not required if skipRepoValidation is set to true.
        """
        return pulumi.get(self, "repo_ids")

    @repo_ids.setter
    def repo_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "repo_ids", value)

    @_builtins.property
    @pulumi.getter(name="requestCascade")
    def request_cascade(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Request cascade to delete the GitOps application.
        """
        return pulumi.get(self, "request_cascade")

    @request_cascade.setter
    def request_cascade(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "request_cascade", value)

    @_builtins.property
    @pulumi.getter(name="requestPropagationPolicy")
    def request_propagation_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Request propagation policy to delete the GitOps application.
        """
        return pulumi.get(self, "request_propagation_policy")

    @request_propagation_policy.setter
    def request_propagation_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "request_propagation_policy", value)

    @_builtins.property
    @pulumi.getter(name="skipRepoValidation")
    def skip_repo_validation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps application should skip validate repository definition exists.
        """
        return pulumi.get(self, "skip_repo_validation")

    @skip_repo_validation.setter
    def skip_repo_validation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_repo_validation", value)

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @upsert.setter
    def upsert(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "upsert", value)

    @_builtins.property
    @pulumi.getter
    def validate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps application yaml has to be validated.
        """
        return pulumi.get(self, "validate")

    @validate.setter
    def validate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "validate", value)


@pulumi.input_type
class _GitOpsApplicationsState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 applications: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsApplicationsApplicationArgs']]]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options_remove_existing_finalizers: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 request_cascade: Optional[pulumi.Input[_builtins.bool]] = None,
                 request_propagation_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_repo_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 validate: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering GitOpsApplications resources.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps application.
        :param pulumi.Input[Sequence[pulumi.Input['GitOpsApplicationsApplicationArgs']]] applications: Definition of the GitOps application resource.
        :param pulumi.Input[_builtins.str] cluster_id: Cluster identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] kind: Kind of the GitOps application.
        :param pulumi.Input[_builtins.str] name: Name of the GitOps application.
        :param pulumi.Input[_builtins.bool] options_remove_existing_finalizers: Options to remove existing finalizers to delete the GitOps application.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] project: The ArgoCD project name corresponding to this GitOps application. An empty string means that the GitOps application belongs to the default project created by Harness.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] repo_id: Repository identifier of the GitOps application. When using skipRepoValidation, this field is not required.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] repo_ids: List of repository identifiers of the GitOps for Multi-Source application. Not required if skipRepoValidation is set to true.
        :param pulumi.Input[_builtins.bool] request_cascade: Request cascade to delete the GitOps application.
        :param pulumi.Input[_builtins.str] request_propagation_policy: Request propagation policy to delete the GitOps application.
        :param pulumi.Input[_builtins.bool] skip_repo_validation: Indicates if the GitOps application should skip validate repository definition exists.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps application should be updated if existing and inserted if not.
        :param pulumi.Input[_builtins.bool] validate: Indicates if the GitOps application yaml has to be validated.
        """
        if account_id is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""account_id is deprecated: This field is deprecated and will be removed in a future release.""")
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if agent_id is not None:
            pulumi.set(__self__, "agent_id", agent_id)
        if applications is not None:
            pulumi.set(__self__, "applications", applications)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if identifier is not None:
            warnings.warn("""This field is deprecated and will be removed in a future release.""", DeprecationWarning)
            pulumi.log.warn("""identifier is deprecated: This field is deprecated and will be removed in a future release.""")
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if options_remove_existing_finalizers is not None:
            pulumi.set(__self__, "options_remove_existing_finalizers", options_remove_existing_finalizers)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if repo_id is not None:
            pulumi.set(__self__, "repo_id", repo_id)
        if repo_ids is not None:
            pulumi.set(__self__, "repo_ids", repo_ids)
        if request_cascade is not None:
            pulumi.set(__self__, "request_cascade", request_cascade)
        if request_propagation_policy is not None:
            pulumi.set(__self__, "request_propagation_policy", request_propagation_policy)
        if skip_repo_validation is not None:
            pulumi.set(__self__, "skip_repo_validation", skip_repo_validation)
        if upsert is not None:
            pulumi.set(__self__, "upsert", upsert)
        if validate is not None:
            pulumi.set(__self__, "validate", validate)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account identifier of the GitOps application.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Agent identifier of the GitOps application.
        """
        return pulumi.get(self, "agent_id")

    @agent_id.setter
    def agent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_id", value)

    @_builtins.property
    @pulumi.getter
    def applications(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsApplicationsApplicationArgs']]]]:
        """
        Definition of the GitOps application resource.
        """
        return pulumi.get(self, "applications")

    @applications.setter
    def applications(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GitOpsApplicationsApplicationArgs']]]]):
        pulumi.set(self, "applications", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Cluster identifier of the GitOps application.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the GitOps application.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Kind of the GitOps application.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kind", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the GitOps application.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="optionsRemoveExistingFinalizers")
    def options_remove_existing_finalizers(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Options to remove existing finalizers to delete the GitOps application.
        """
        return pulumi.get(self, "options_remove_existing_finalizers")

    @options_remove_existing_finalizers.setter
    def options_remove_existing_finalizers(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "options_remove_existing_finalizers", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization identifier of the GitOps application.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ArgoCD project name corresponding to this GitOps application. An empty string means that the GitOps application belongs to the default project created by Harness.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier of the GitOps application.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="repoId")
    def repo_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository identifier of the GitOps application. When using skipRepoValidation, this field is not required.
        """
        return pulumi.get(self, "repo_id")

    @repo_id.setter
    def repo_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repo_id", value)

    @_builtins.property
    @pulumi.getter(name="repoIds")
    def repo_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of repository identifiers of the GitOps for Multi-Source application. Not required if skipRepoValidation is set to true.
        """
        return pulumi.get(self, "repo_ids")

    @repo_ids.setter
    def repo_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "repo_ids", value)

    @_builtins.property
    @pulumi.getter(name="requestCascade")
    def request_cascade(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Request cascade to delete the GitOps application.
        """
        return pulumi.get(self, "request_cascade")

    @request_cascade.setter
    def request_cascade(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "request_cascade", value)

    @_builtins.property
    @pulumi.getter(name="requestPropagationPolicy")
    def request_propagation_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Request propagation policy to delete the GitOps application.
        """
        return pulumi.get(self, "request_propagation_policy")

    @request_propagation_policy.setter
    def request_propagation_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "request_propagation_policy", value)

    @_builtins.property
    @pulumi.getter(name="skipRepoValidation")
    def skip_repo_validation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps application should skip validate repository definition exists.
        """
        return pulumi.get(self, "skip_repo_validation")

    @skip_repo_validation.setter
    def skip_repo_validation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_repo_validation", value)

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @upsert.setter
    def upsert(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "upsert", value)

    @_builtins.property
    @pulumi.getter
    def validate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the GitOps application yaml has to be validated.
        """
        return pulumi.get(self, "validate")

    @validate.setter
    def validate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "validate", value)


@pulumi.type_token("harness:platform/gitOpsApplications:GitOpsApplications")
class GitOpsApplications(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 applications: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsApplicationsApplicationArgs', 'GitOpsApplicationsApplicationArgsDict']]]]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options_remove_existing_finalizers: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 request_cascade: Optional[pulumi.Input[_builtins.bool]] = None,
                 request_propagation_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_repo_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 validate: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Resource for managing a Harness Gitops Application.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.GitOpsApplications("example",
            applications=[{
                "metadatas": [{
                    "annotations": {},
                    "labels": {
                        "harness.io/serviceRef": "service_id",
                        "harness.io/envRef": "env_id",
                    },
                    "name": "appname123",
                }],
                "specs": [{
                    "sync_policies": [{
                        "sync_options": [
                            "PrunePropagationPolicy=undefined",
                            "CreateNamespace=false",
                            "Validate=false",
                            "skipSchemaValidations=false",
                            "autoCreateNamespace=false",
                            "pruneLast=false",
                            "applyOutofSyncOnly=false",
                            "Replace=false",
                            "retry=false",
                        ],
                    }],
                    "sources": [{
                        "target_revision": "master",
                        "repo_url": "https://github.com/willycoll/argocd-example-apps.git",
                        "path": "helm-guestbook",
                    }],
                    "destinations": [{
                        "namespace": "namespace-123",
                        "server": "https://1.3.4.5",
                    }],
                }],
            }],
            project_id="project_id",
            org_id="org_id",
            account_id="account_id",
            identifier="identifier",
            cluster_id="cluster_id",
            repo_id="repo_id",
            agent_id="agent_id")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import a Project level Gitops Application

        ```sh
        $ pulumi import harness:platform/gitOpsApplications:GitOpsApplications example <organization_id>/<project_id>/<agent_id>/<app_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps application.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitOpsApplicationsApplicationArgs', 'GitOpsApplicationsApplicationArgsDict']]]] applications: Definition of the GitOps application resource.
        :param pulumi.Input[_builtins.str] cluster_id: Cluster identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] kind: Kind of the GitOps application.
        :param pulumi.Input[_builtins.str] name: Name of the GitOps application.
        :param pulumi.Input[_builtins.bool] options_remove_existing_finalizers: Options to remove existing finalizers to delete the GitOps application.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] project: The ArgoCD project name corresponding to this GitOps application. An empty string means that the GitOps application belongs to the default project created by Harness.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] repo_id: Repository identifier of the GitOps application. When using skipRepoValidation, this field is not required.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] repo_ids: List of repository identifiers of the GitOps for Multi-Source application. Not required if skipRepoValidation is set to true.
        :param pulumi.Input[_builtins.bool] request_cascade: Request cascade to delete the GitOps application.
        :param pulumi.Input[_builtins.str] request_propagation_policy: Request propagation policy to delete the GitOps application.
        :param pulumi.Input[_builtins.bool] skip_repo_validation: Indicates if the GitOps application should skip validate repository definition exists.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps application should be updated if existing and inserted if not.
        :param pulumi.Input[_builtins.bool] validate: Indicates if the GitOps application yaml has to be validated.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GitOpsApplicationsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing a Harness Gitops Application.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.GitOpsApplications("example",
            applications=[{
                "metadatas": [{
                    "annotations": {},
                    "labels": {
                        "harness.io/serviceRef": "service_id",
                        "harness.io/envRef": "env_id",
                    },
                    "name": "appname123",
                }],
                "specs": [{
                    "sync_policies": [{
                        "sync_options": [
                            "PrunePropagationPolicy=undefined",
                            "CreateNamespace=false",
                            "Validate=false",
                            "skipSchemaValidations=false",
                            "autoCreateNamespace=false",
                            "pruneLast=false",
                            "applyOutofSyncOnly=false",
                            "Replace=false",
                            "retry=false",
                        ],
                    }],
                    "sources": [{
                        "target_revision": "master",
                        "repo_url": "https://github.com/willycoll/argocd-example-apps.git",
                        "path": "helm-guestbook",
                    }],
                    "destinations": [{
                        "namespace": "namespace-123",
                        "server": "https://1.3.4.5",
                    }],
                }],
            }],
            project_id="project_id",
            org_id="org_id",
            account_id="account_id",
            identifier="identifier",
            cluster_id="cluster_id",
            repo_id="repo_id",
            agent_id="agent_id")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import a Project level Gitops Application

        ```sh
        $ pulumi import harness:platform/gitOpsApplications:GitOpsApplications example <organization_id>/<project_id>/<agent_id>/<app_name>
        ```

        :param str resource_name: The name of the resource.
        :param GitOpsApplicationsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GitOpsApplicationsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 applications: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsApplicationsApplicationArgs', 'GitOpsApplicationsApplicationArgsDict']]]]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 options_remove_existing_finalizers: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 request_cascade: Optional[pulumi.Input[_builtins.bool]] = None,
                 request_propagation_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_repo_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 upsert: Optional[pulumi.Input[_builtins.bool]] = None,
                 validate: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GitOpsApplicationsArgs.__new__(GitOpsApplicationsArgs)

            __props__.__dict__["account_id"] = account_id
            if agent_id is None and not opts.urn:
                raise TypeError("Missing required property 'agent_id'")
            __props__.__dict__["agent_id"] = agent_id
            if applications is None and not opts.urn:
                raise TypeError("Missing required property 'applications'")
            __props__.__dict__["applications"] = applications
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["kind"] = kind
            __props__.__dict__["name"] = name
            __props__.__dict__["options_remove_existing_finalizers"] = options_remove_existing_finalizers
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project"] = project
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["repo_id"] = repo_id
            __props__.__dict__["repo_ids"] = repo_ids
            __props__.__dict__["request_cascade"] = request_cascade
            __props__.__dict__["request_propagation_policy"] = request_propagation_policy
            __props__.__dict__["skip_repo_validation"] = skip_repo_validation
            __props__.__dict__["upsert"] = upsert
            __props__.__dict__["validate"] = validate
        super(GitOpsApplications, __self__).__init__(
            'harness:platform/gitOpsApplications:GitOpsApplications',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            agent_id: Optional[pulumi.Input[_builtins.str]] = None,
            applications: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GitOpsApplicationsApplicationArgs', 'GitOpsApplicationsApplicationArgsDict']]]]] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            kind: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            options_remove_existing_finalizers: Optional[pulumi.Input[_builtins.bool]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            repo_id: Optional[pulumi.Input[_builtins.str]] = None,
            repo_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            request_cascade: Optional[pulumi.Input[_builtins.bool]] = None,
            request_propagation_policy: Optional[pulumi.Input[_builtins.str]] = None,
            skip_repo_validation: Optional[pulumi.Input[_builtins.bool]] = None,
            upsert: Optional[pulumi.Input[_builtins.bool]] = None,
            validate: Optional[pulumi.Input[_builtins.bool]] = None) -> 'GitOpsApplications':
        """
        Get an existing GitOpsApplications resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] agent_id: Agent identifier of the GitOps application.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GitOpsApplicationsApplicationArgs', 'GitOpsApplicationsApplicationArgsDict']]]] applications: Definition of the GitOps application resource.
        :param pulumi.Input[_builtins.str] cluster_id: Cluster identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] kind: Kind of the GitOps application.
        :param pulumi.Input[_builtins.str] name: Name of the GitOps application.
        :param pulumi.Input[_builtins.bool] options_remove_existing_finalizers: Options to remove existing finalizers to delete the GitOps application.
        :param pulumi.Input[_builtins.str] org_id: Organization identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] project: The ArgoCD project name corresponding to this GitOps application. An empty string means that the GitOps application belongs to the default project created by Harness.
        :param pulumi.Input[_builtins.str] project_id: Project identifier of the GitOps application.
        :param pulumi.Input[_builtins.str] repo_id: Repository identifier of the GitOps application. When using skipRepoValidation, this field is not required.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] repo_ids: List of repository identifiers of the GitOps for Multi-Source application. Not required if skipRepoValidation is set to true.
        :param pulumi.Input[_builtins.bool] request_cascade: Request cascade to delete the GitOps application.
        :param pulumi.Input[_builtins.str] request_propagation_policy: Request propagation policy to delete the GitOps application.
        :param pulumi.Input[_builtins.bool] skip_repo_validation: Indicates if the GitOps application should skip validate repository definition exists.
        :param pulumi.Input[_builtins.bool] upsert: Indicates if the GitOps application should be updated if existing and inserted if not.
        :param pulumi.Input[_builtins.bool] validate: Indicates if the GitOps application yaml has to be validated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GitOpsApplicationsState.__new__(_GitOpsApplicationsState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["agent_id"] = agent_id
        __props__.__dict__["applications"] = applications
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["kind"] = kind
        __props__.__dict__["name"] = name
        __props__.__dict__["options_remove_existing_finalizers"] = options_remove_existing_finalizers
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project"] = project
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["repo_id"] = repo_id
        __props__.__dict__["repo_ids"] = repo_ids
        __props__.__dict__["request_cascade"] = request_cascade
        __props__.__dict__["request_propagation_policy"] = request_propagation_policy
        __props__.__dict__["skip_repo_validation"] = skip_repo_validation
        __props__.__dict__["upsert"] = upsert
        __props__.__dict__["validate"] = validate
        return GitOpsApplications(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account identifier of the GitOps application.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> pulumi.Output[_builtins.str]:
        """
        Agent identifier of the GitOps application.
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter
    def applications(self) -> pulumi.Output[Sequence['outputs.GitOpsApplicationsApplication']]:
        """
        Definition of the GitOps application resource.
        """
        return pulumi.get(self, "applications")

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        Cluster identifier of the GitOps application.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def identifier(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Identifier of the GitOps application.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Kind of the GitOps application.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the GitOps application.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="optionsRemoveExistingFinalizers")
    def options_remove_existing_finalizers(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Options to remove existing finalizers to delete the GitOps application.
        """
        return pulumi.get(self, "options_remove_existing_finalizers")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Organization identifier of the GitOps application.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The ArgoCD project name corresponding to this GitOps application. An empty string means that the GitOps application belongs to the default project created by Harness.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Project identifier of the GitOps application.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="repoId")
    def repo_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Repository identifier of the GitOps application. When using skipRepoValidation, this field is not required.
        """
        return pulumi.get(self, "repo_id")

    @_builtins.property
    @pulumi.getter(name="repoIds")
    def repo_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of repository identifiers of the GitOps for Multi-Source application. Not required if skipRepoValidation is set to true.
        """
        return pulumi.get(self, "repo_ids")

    @_builtins.property
    @pulumi.getter(name="requestCascade")
    def request_cascade(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Request cascade to delete the GitOps application.
        """
        return pulumi.get(self, "request_cascade")

    @_builtins.property
    @pulumi.getter(name="requestPropagationPolicy")
    def request_propagation_policy(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Request propagation policy to delete the GitOps application.
        """
        return pulumi.get(self, "request_propagation_policy")

    @_builtins.property
    @pulumi.getter(name="skipRepoValidation")
    def skip_repo_validation(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the GitOps application should skip validate repository definition exists.
        """
        return pulumi.get(self, "skip_repo_validation")

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @_builtins.property
    @pulumi.getter
    def validate(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the GitOps application yaml has to be validated.
        """
        return pulumi.get(self, "validate")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAzureGatewayResult',
    'AwaitableGetAzureGatewayResult',
    'get_azure_gateway',
    'get_azure_gateway_output',
]

@pulumi.output_type
class GetAzureGatewayResult:
    """
    A collection of values returned by getAzureGateway.
    """
    def __init__(__self__, app_gateway_id=None, azure_func_region=None, certificate_id=None, cloud_connector_id=None, delete_cloud_resources_on_destroy=None, frontend_ip=None, host_name=None, id=None, identifier=None, name=None, region=None, resource_group=None, sku_size=None, subnet_id=None, vpc=None):
        if app_gateway_id and not isinstance(app_gateway_id, str):
            raise TypeError("Expected argument 'app_gateway_id' to be a str")
        pulumi.set(__self__, "app_gateway_id", app_gateway_id)
        if azure_func_region and not isinstance(azure_func_region, str):
            raise TypeError("Expected argument 'azure_func_region' to be a str")
        pulumi.set(__self__, "azure_func_region", azure_func_region)
        if certificate_id and not isinstance(certificate_id, str):
            raise TypeError("Expected argument 'certificate_id' to be a str")
        pulumi.set(__self__, "certificate_id", certificate_id)
        if cloud_connector_id and not isinstance(cloud_connector_id, str):
            raise TypeError("Expected argument 'cloud_connector_id' to be a str")
        pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        if delete_cloud_resources_on_destroy and not isinstance(delete_cloud_resources_on_destroy, bool):
            raise TypeError("Expected argument 'delete_cloud_resources_on_destroy' to be a bool")
        pulumi.set(__self__, "delete_cloud_resources_on_destroy", delete_cloud_resources_on_destroy)
        if frontend_ip and not isinstance(frontend_ip, str):
            raise TypeError("Expected argument 'frontend_ip' to be a str")
        pulumi.set(__self__, "frontend_ip", frontend_ip)
        if host_name and not isinstance(host_name, str):
            raise TypeError("Expected argument 'host_name' to be a str")
        pulumi.set(__self__, "host_name", host_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if resource_group and not isinstance(resource_group, str):
            raise TypeError("Expected argument 'resource_group' to be a str")
        pulumi.set(__self__, "resource_group", resource_group)
        if sku_size and not isinstance(sku_size, str):
            raise TypeError("Expected argument 'sku_size' to be a str")
        pulumi.set(__self__, "sku_size", sku_size)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if vpc and not isinstance(vpc, str):
            raise TypeError("Expected argument 'vpc' to be a str")
        pulumi.set(__self__, "vpc", vpc)

    @_builtins.property
    @pulumi.getter(name="appGatewayId")
    def app_gateway_id(self) -> Optional[_builtins.str]:
        """
        ID of Azure AppGateway for importing
        """
        return pulumi.get(self, "app_gateway_id")

    @_builtins.property
    @pulumi.getter(name="azureFuncRegion")
    def azure_func_region(self) -> _builtins.str:
        """
        Region in which azure cloud function will be provisioned
        """
        return pulumi.get(self, "azure_func_region")

    @_builtins.property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[_builtins.str]:
        """
        ID of existing SSL certificate from AppGateway being imported. Required only for SSL based rules
        """
        return pulumi.get(self, "certificate_id")

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> _builtins.str:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @_builtins.property
    @pulumi.getter(name="deleteCloudResourcesOnDestroy")
    def delete_cloud_resources_on_destroy(self) -> _builtins.bool:
        return pulumi.get(self, "delete_cloud_resources_on_destroy")

    @_builtins.property
    @pulumi.getter(name="frontendIp")
    def frontend_ip(self) -> Optional[_builtins.str]:
        """
        ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
        """
        return pulumi.get(self, "frontend_ip")

    @_builtins.property
    @pulumi.getter(name="hostName")
    def host_name(self) -> _builtins.str:
        """
        Hostname for the proxy
        """
        return pulumi.get(self, "host_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the proxy
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        Region in which cloud resources are hosted
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="resourceGroup")
    def resource_group(self) -> _builtins.str:
        """
        Resource group in which cloud resources are hosted
        """
        return pulumi.get(self, "resource_group")

    @_builtins.property
    @pulumi.getter(name="skuSize")
    def sku_size(self) -> Optional[_builtins.str]:
        """
        Size of machine used for the gateway
        """
        return pulumi.get(self, "sku_size")

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[_builtins.str]:
        """
        Subnet in which cloud resources are hosted
        """
        return pulumi.get(self, "subnet_id")

    @_builtins.property
    @pulumi.getter
    def vpc(self) -> _builtins.str:
        """
        VPC in which cloud resources are hosted
        """
        return pulumi.get(self, "vpc")


class AwaitableGetAzureGatewayResult(GetAzureGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAzureGatewayResult(
            app_gateway_id=self.app_gateway_id,
            azure_func_region=self.azure_func_region,
            certificate_id=self.certificate_id,
            cloud_connector_id=self.cloud_connector_id,
            delete_cloud_resources_on_destroy=self.delete_cloud_resources_on_destroy,
            frontend_ip=self.frontend_ip,
            host_name=self.host_name,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            region=self.region,
            resource_group=self.resource_group,
            sku_size=self.sku_size,
            subnet_id=self.subnet_id,
            vpc=self.vpc)


def get_azure_gateway(app_gateway_id: Optional[_builtins.str] = None,
                      azure_func_region: Optional[_builtins.str] = None,
                      certificate_id: Optional[_builtins.str] = None,
                      cloud_connector_id: Optional[_builtins.str] = None,
                      delete_cloud_resources_on_destroy: Optional[_builtins.bool] = None,
                      frontend_ip: Optional[_builtins.str] = None,
                      host_name: Optional[_builtins.str] = None,
                      name: Optional[_builtins.str] = None,
                      region: Optional[_builtins.str] = None,
                      resource_group: Optional[_builtins.str] = None,
                      sku_size: Optional[_builtins.str] = None,
                      subnet_id: Optional[_builtins.str] = None,
                      vpc: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAzureGatewayResult:
    """
    Data source for AWS Autostopping proxy

    ## Example Usage


    :param _builtins.str app_gateway_id: ID of Azure AppGateway for importing
    :param _builtins.str azure_func_region: Region in which azure cloud function will be provisioned
    :param _builtins.str certificate_id: ID of existing SSL certificate from AppGateway being imported. Required only for SSL based rules
    :param _builtins.str cloud_connector_id: Id of the cloud connector
    :param _builtins.str frontend_ip: ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
    :param _builtins.str host_name: Hostname for the proxy
    :param _builtins.str name: Name of the proxy
    :param _builtins.str region: Region in which cloud resources are hosted
    :param _builtins.str resource_group: Resource group in which cloud resources are hosted
    :param _builtins.str sku_size: Size of machine used for the gateway
    :param _builtins.str subnet_id: Subnet in which cloud resources are hosted
    :param _builtins.str vpc: VPC in which cloud resources are hosted
    """
    __args__ = dict()
    __args__['appGatewayId'] = app_gateway_id
    __args__['azureFuncRegion'] = azure_func_region
    __args__['certificateId'] = certificate_id
    __args__['cloudConnectorId'] = cloud_connector_id
    __args__['deleteCloudResourcesOnDestroy'] = delete_cloud_resources_on_destroy
    __args__['frontendIp'] = frontend_ip
    __args__['hostName'] = host_name
    __args__['name'] = name
    __args__['region'] = region
    __args__['resourceGroup'] = resource_group
    __args__['skuSize'] = sku_size
    __args__['subnetId'] = subnet_id
    __args__['vpc'] = vpc
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:autostopping/getAzureGateway:getAzureGateway', __args__, opts=opts, typ=GetAzureGatewayResult).value

    return AwaitableGetAzureGatewayResult(
        app_gateway_id=pulumi.get(__ret__, 'app_gateway_id'),
        azure_func_region=pulumi.get(__ret__, 'azure_func_region'),
        certificate_id=pulumi.get(__ret__, 'certificate_id'),
        cloud_connector_id=pulumi.get(__ret__, 'cloud_connector_id'),
        delete_cloud_resources_on_destroy=pulumi.get(__ret__, 'delete_cloud_resources_on_destroy'),
        frontend_ip=pulumi.get(__ret__, 'frontend_ip'),
        host_name=pulumi.get(__ret__, 'host_name'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'),
        resource_group=pulumi.get(__ret__, 'resource_group'),
        sku_size=pulumi.get(__ret__, 'sku_size'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        vpc=pulumi.get(__ret__, 'vpc'))
def get_azure_gateway_output(app_gateway_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             azure_func_region: Optional[pulumi.Input[_builtins.str]] = None,
                             certificate_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                             delete_cloud_resources_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                             frontend_ip: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             host_name: Optional[pulumi.Input[_builtins.str]] = None,
                             name: Optional[pulumi.Input[_builtins.str]] = None,
                             region: Optional[pulumi.Input[_builtins.str]] = None,
                             resource_group: Optional[pulumi.Input[_builtins.str]] = None,
                             sku_size: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             subnet_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             vpc: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAzureGatewayResult]:
    """
    Data source for AWS Autostopping proxy

    ## Example Usage


    :param _builtins.str app_gateway_id: ID of Azure AppGateway for importing
    :param _builtins.str azure_func_region: Region in which azure cloud function will be provisioned
    :param _builtins.str certificate_id: ID of existing SSL certificate from AppGateway being imported. Required only for SSL based rules
    :param _builtins.str cloud_connector_id: Id of the cloud connector
    :param _builtins.str frontend_ip: ID of IP address to be used. Required only for creating new AppGateway. See https://learn.microsoft.com/en-us/azure/application-gateway/application-gateway-components#static-versus-dynamic-public-ip-address for more details
    :param _builtins.str host_name: Hostname for the proxy
    :param _builtins.str name: Name of the proxy
    :param _builtins.str region: Region in which cloud resources are hosted
    :param _builtins.str resource_group: Resource group in which cloud resources are hosted
    :param _builtins.str sku_size: Size of machine used for the gateway
    :param _builtins.str subnet_id: Subnet in which cloud resources are hosted
    :param _builtins.str vpc: VPC in which cloud resources are hosted
    """
    __args__ = dict()
    __args__['appGatewayId'] = app_gateway_id
    __args__['azureFuncRegion'] = azure_func_region
    __args__['certificateId'] = certificate_id
    __args__['cloudConnectorId'] = cloud_connector_id
    __args__['deleteCloudResourcesOnDestroy'] = delete_cloud_resources_on_destroy
    __args__['frontendIp'] = frontend_ip
    __args__['hostName'] = host_name
    __args__['name'] = name
    __args__['region'] = region
    __args__['resourceGroup'] = resource_group
    __args__['skuSize'] = sku_size
    __args__['subnetId'] = subnet_id
    __args__['vpc'] = vpc
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:autostopping/getAzureGateway:getAzureGateway', __args__, opts=opts, typ=GetAzureGatewayResult)
    return __ret__.apply(lambda __response__: GetAzureGatewayResult(
        app_gateway_id=pulumi.get(__response__, 'app_gateway_id'),
        azure_func_region=pulumi.get(__response__, 'azure_func_region'),
        certificate_id=pulumi.get(__response__, 'certificate_id'),
        cloud_connector_id=pulumi.get(__response__, 'cloud_connector_id'),
        delete_cloud_resources_on_destroy=pulumi.get(__response__, 'delete_cloud_resources_on_destroy'),
        frontend_ip=pulumi.get(__response__, 'frontend_ip'),
        host_name=pulumi.get(__response__, 'host_name'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region'),
        resource_group=pulumi.get(__response__, 'resource_group'),
        sku_size=pulumi.get(__response__, 'sku_size'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        vpc=pulumi.get(__response__, 'vpc')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DelegatetokenArgs', 'Delegatetoken']

@pulumi.input_type
class DelegatetokenArgs:
    def __init__(__self__, *,
                 account_id: pulumi.Input[_builtins.str],
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 revoke_after: Optional[pulumi.Input[_builtins.int]] = None,
                 token_status: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Delegatetoken resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.int] created_at: Time when the delegate token is created. This is an epoch timestamp.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] created_by: created by details
        :param pulumi.Input[_builtins.str] name: Name of the delegate token
        :param pulumi.Input[_builtins.str] org_id: Org Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[_builtins.int] revoke_after: Epoch time in milliseconds after which the token will be marked as revoked. There can be a delay of up to one hour from the epoch value provided and actual revoking of the token.
        :param pulumi.Input[_builtins.str] token_status: Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
        :param pulumi.Input[_builtins.str] value: Value of the delegate token. Encoded in base64.
        """
        pulumi.set(__self__, "account_id", account_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if purge_on_delete is not None:
            pulumi.set(__self__, "purge_on_delete", purge_on_delete)
        if revoke_after is not None:
            pulumi.set(__self__, "revoke_after", revoke_after)
        if token_status is not None:
            pulumi.set(__self__, "token_status", token_status)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Input[_builtins.str]:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time when the delegate token is created. This is an epoch timestamp.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        created by details
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the delegate token
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Org Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="purgeOnDelete")
    def purge_on_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "purge_on_delete")

    @purge_on_delete.setter
    def purge_on_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "purge_on_delete", value)

    @_builtins.property
    @pulumi.getter(name="revokeAfter")
    def revoke_after(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Epoch time in milliseconds after which the token will be marked as revoked. There can be a delay of up to one hour from the epoch value provided and actual revoking of the token.
        """
        return pulumi.get(self, "revoke_after")

    @revoke_after.setter
    def revoke_after(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "revoke_after", value)

    @_builtins.property
    @pulumi.getter(name="tokenStatus")
    def token_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
        """
        return pulumi.get(self, "token_status")

    @token_status.setter
    def token_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token_status", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Value of the delegate token. Encoded in base64.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class _DelegatetokenState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 revoke_after: Optional[pulumi.Input[_builtins.int]] = None,
                 token_status: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Delegatetoken resources.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.int] created_at: Time when the delegate token is created. This is an epoch timestamp.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] created_by: created by details
        :param pulumi.Input[_builtins.str] name: Name of the delegate token
        :param pulumi.Input[_builtins.str] org_id: Org Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[_builtins.int] revoke_after: Epoch time in milliseconds after which the token will be marked as revoked. There can be a delay of up to one hour from the epoch value provided and actual revoking of the token.
        :param pulumi.Input[_builtins.str] token_status: Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
        :param pulumi.Input[_builtins.str] value: Value of the delegate token. Encoded in base64.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if purge_on_delete is not None:
            pulumi.set(__self__, "purge_on_delete", purge_on_delete)
        if revoke_after is not None:
            pulumi.set(__self__, "revoke_after", revoke_after)
        if token_status is not None:
            pulumi.set(__self__, "token_status", token_status)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time when the delegate token is created. This is an epoch timestamp.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        created by details
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the delegate token
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Org Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="purgeOnDelete")
    def purge_on_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "purge_on_delete")

    @purge_on_delete.setter
    def purge_on_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "purge_on_delete", value)

    @_builtins.property
    @pulumi.getter(name="revokeAfter")
    def revoke_after(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Epoch time in milliseconds after which the token will be marked as revoked. There can be a delay of up to one hour from the epoch value provided and actual revoking of the token.
        """
        return pulumi.get(self, "revoke_after")

    @revoke_after.setter
    def revoke_after(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "revoke_after", value)

    @_builtins.property
    @pulumi.getter(name="tokenStatus")
    def token_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
        """
        return pulumi.get(self, "token_status")

    @token_status.setter
    def token_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token_status", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Value of the delegate token. Encoded in base64.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


@pulumi.type_token("harness:platform/delegatetoken:Delegatetoken")
class Delegatetoken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 revoke_after: Optional[pulumi.Input[_builtins.int]] = None,
                 token_status: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating delegate tokens. Delegate tokens can be created and revoked. Revoked tokens immediately stop functioning and are only purged after 30 days, meaning you cannot recreate a token with the same name within that period.
        To revoke a token, set token_status field to "REVOKED".

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Create delegate token at account level
        account_level = harness.platform.Delegatetoken("account_level",
            name="account-delegate-token",
            account_id="account_id")
        # Create delegate token at organization level
        org_level = harness.platform.Delegatetoken("org_level",
            name="org-delegate-token",
            account_id="account_id",
            org_id="org_id")
        # Create delegate token at project level
        project_level = harness.platform.Delegatetoken("project_level",
            name="project-delegate-token",
            account_id="account_id",
            org_id="org_id",
            project_id="project_id")
        # Create delegate token with auto-expiry
        expiry_token = harness.platform.Delegatetoken("expiry_token",
            name="expiry-delegate-token",
            account_id="account_id",
            revoke_after=1769689600000)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.int] created_at: Time when the delegate token is created. This is an epoch timestamp.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] created_by: created by details
        :param pulumi.Input[_builtins.str] name: Name of the delegate token
        :param pulumi.Input[_builtins.str] org_id: Org Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[_builtins.int] revoke_after: Epoch time in milliseconds after which the token will be marked as revoked. There can be a delay of up to one hour from the epoch value provided and actual revoking of the token.
        :param pulumi.Input[_builtins.str] token_status: Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
        :param pulumi.Input[_builtins.str] value: Value of the delegate token. Encoded in base64.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DelegatetokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating delegate tokens. Delegate tokens can be created and revoked. Revoked tokens immediately stop functioning and are only purged after 30 days, meaning you cannot recreate a token with the same name within that period.
        To revoke a token, set token_status field to "REVOKED".

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # Create delegate token at account level
        account_level = harness.platform.Delegatetoken("account_level",
            name="account-delegate-token",
            account_id="account_id")
        # Create delegate token at organization level
        org_level = harness.platform.Delegatetoken("org_level",
            name="org-delegate-token",
            account_id="account_id",
            org_id="org_id")
        # Create delegate token at project level
        project_level = harness.platform.Delegatetoken("project_level",
            name="project-delegate-token",
            account_id="account_id",
            org_id="org_id",
            project_id="project_id")
        # Create delegate token with auto-expiry
        expiry_token = harness.platform.Delegatetoken("expiry_token",
            name="expiry-delegate-token",
            account_id="account_id",
            revoke_after=1769689600000)
        ```

        :param str resource_name: The name of the resource.
        :param DelegatetokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DelegatetokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 revoke_after: Optional[pulumi.Input[_builtins.int]] = None,
                 token_status: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DelegatetokenArgs.__new__(DelegatetokenArgs)

            if account_id is None and not opts.urn:
                raise TypeError("Missing required property 'account_id'")
            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["created_at"] = created_at
            __props__.__dict__["created_by"] = created_by
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["purge_on_delete"] = purge_on_delete
            __props__.__dict__["revoke_after"] = revoke_after
            __props__.__dict__["token_status"] = token_status
            __props__.__dict__["value"] = value
        super(Delegatetoken, __self__).__init__(
            'harness:platform/delegatetoken:Delegatetoken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.int]] = None,
            created_by: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            revoke_after: Optional[pulumi.Input[_builtins.int]] = None,
            token_status: Optional[pulumi.Input[_builtins.str]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None) -> 'Delegatetoken':
        """
        Get an existing Delegatetoken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.int] created_at: Time when the delegate token is created. This is an epoch timestamp.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] created_by: created by details
        :param pulumi.Input[_builtins.str] name: Name of the delegate token
        :param pulumi.Input[_builtins.str] org_id: Org Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[_builtins.int] revoke_after: Epoch time in milliseconds after which the token will be marked as revoked. There can be a delay of up to one hour from the epoch value provided and actual revoking of the token.
        :param pulumi.Input[_builtins.str] token_status: Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
        :param pulumi.Input[_builtins.str] value: Value of the delegate token. Encoded in base64.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DelegatetokenState.__new__(_DelegatetokenState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["purge_on_delete"] = purge_on_delete
        __props__.__dict__["revoke_after"] = revoke_after
        __props__.__dict__["token_status"] = token_status
        __props__.__dict__["value"] = value
        return Delegatetoken(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.int]:
        """
        Time when the delegate token is created. This is an epoch timestamp.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[Mapping[str, _builtins.str]]:
        """
        created by details
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the delegate token
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Org Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="purgeOnDelete")
    def purge_on_delete(self) -> pulumi.Output[Optional[_builtins.bool]]:
        return pulumi.get(self, "purge_on_delete")

    @_builtins.property
    @pulumi.getter(name="revokeAfter")
    def revoke_after(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Epoch time in milliseconds after which the token will be marked as revoked. There can be a delay of up to one hour from the epoch value provided and actual revoking of the token.
        """
        return pulumi.get(self, "revoke_after")

    @_builtins.property
    @pulumi.getter(name="tokenStatus")
    def token_status(self) -> pulumi.Output[_builtins.str]:
        """
        Status of Delegate Token (ACTIVE or REVOKED). If left empty both active and revoked tokens will be assumed
        """
        return pulumi.get(self, "token_status")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[_builtins.str]:
        """
        Value of the delegate token. Encoded in base64.
        """
        return pulumi.get(self, "value")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRuleRdsResult',
    'AwaitableGetRuleRdsResult',
    'get_rule_rds',
    'get_rule_rds_output',
]

@pulumi.output_type
class GetRuleRdsResult:
    """
    A collection of values returned by getRuleRds.
    """
    def __init__(__self__, cloud_connector_id=None, database=None, depends=None, id=None, identifier=None, idle_time_mins=None, name=None, tcps=None):
        if cloud_connector_id and not isinstance(cloud_connector_id, str):
            raise TypeError("Expected argument 'cloud_connector_id' to be a str")
        pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        if database and not isinstance(database, dict):
            raise TypeError("Expected argument 'database' to be a dict")
        pulumi.set(__self__, "database", database)
        if depends and not isinstance(depends, list):
            raise TypeError("Expected argument 'depends' to be a list")
        pulumi.set(__self__, "depends", depends)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, float):
            raise TypeError("Expected argument 'identifier' to be a float")
        pulumi.set(__self__, "identifier", identifier)
        if idle_time_mins and not isinstance(idle_time_mins, int):
            raise TypeError("Expected argument 'idle_time_mins' to be a int")
        pulumi.set(__self__, "idle_time_mins", idle_time_mins)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if tcps and not isinstance(tcps, list):
            raise TypeError("Expected argument 'tcps' to be a list")
        pulumi.set(__self__, "tcps", tcps)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> _builtins.str:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @_builtins.property
    @pulumi.getter
    def database(self) -> 'outputs.GetRuleRdsDatabaseResult':
        return pulumi.get(self, "database")

    @_builtins.property
    @pulumi.getter
    def depends(self) -> Optional[Sequence['outputs.GetRuleRdsDependResult']]:
        """
        Dependent rules
        """
        return pulumi.get(self, "depends")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.float:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="idleTimeMins")
    def idle_time_mins(self) -> Optional[_builtins.int]:
        """
        Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        """
        return pulumi.get(self, "idle_time_mins")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def tcps(self) -> Optional[Sequence['outputs.GetRuleRdsTcpResult']]:
        """
        TCP routing configuration
        """
        return pulumi.get(self, "tcps")


class AwaitableGetRuleRdsResult(GetRuleRdsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRuleRdsResult(
            cloud_connector_id=self.cloud_connector_id,
            database=self.database,
            depends=self.depends,
            id=self.id,
            identifier=self.identifier,
            idle_time_mins=self.idle_time_mins,
            name=self.name,
            tcps=self.tcps)


def get_rule_rds(cloud_connector_id: Optional[_builtins.str] = None,
                 database: Optional[Union['GetRuleRdsDatabaseArgs', 'GetRuleRdsDatabaseArgsDict']] = None,
                 depends: Optional[Sequence[Union['GetRuleRdsDependArgs', 'GetRuleRdsDependArgsDict']]] = None,
                 idle_time_mins: Optional[_builtins.int] = None,
                 name: Optional[_builtins.str] = None,
                 tcps: Optional[Sequence[Union['GetRuleRdsTcpArgs', 'GetRuleRdsTcpArgsDict']]] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRuleRdsResult:
    """
    Data source for retrieving a Harness AutoStopping rule for RDS databases.

    ## Example Usage


    :param _builtins.str cloud_connector_id: Id of the cloud connector
    :param Sequence[Union['GetRuleRdsDependArgs', 'GetRuleRdsDependArgsDict']] depends: Dependent rules
    :param _builtins.int idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
    :param _builtins.str name: Name of the rule
    :param Sequence[Union['GetRuleRdsTcpArgs', 'GetRuleRdsTcpArgsDict']] tcps: TCP routing configuration
    """
    __args__ = dict()
    __args__['cloudConnectorId'] = cloud_connector_id
    __args__['database'] = database
    __args__['depends'] = depends
    __args__['idleTimeMins'] = idle_time_mins
    __args__['name'] = name
    __args__['tcps'] = tcps
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:autostopping/getRuleRds:getRuleRds', __args__, opts=opts, typ=GetRuleRdsResult).value

    return AwaitableGetRuleRdsResult(
        cloud_connector_id=pulumi.get(__ret__, 'cloud_connector_id'),
        database=pulumi.get(__ret__, 'database'),
        depends=pulumi.get(__ret__, 'depends'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        idle_time_mins=pulumi.get(__ret__, 'idle_time_mins'),
        name=pulumi.get(__ret__, 'name'),
        tcps=pulumi.get(__ret__, 'tcps'))
def get_rule_rds_output(cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                        database: Optional[pulumi.Input[Union['GetRuleRdsDatabaseArgs', 'GetRuleRdsDatabaseArgsDict']]] = None,
                        depends: Optional[pulumi.Input[Optional[Sequence[Union['GetRuleRdsDependArgs', 'GetRuleRdsDependArgsDict']]]]] = None,
                        idle_time_mins: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                        name: Optional[pulumi.Input[_builtins.str]] = None,
                        tcps: Optional[pulumi.Input[Optional[Sequence[Union['GetRuleRdsTcpArgs', 'GetRuleRdsTcpArgsDict']]]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRuleRdsResult]:
    """
    Data source for retrieving a Harness AutoStopping rule for RDS databases.

    ## Example Usage


    :param _builtins.str cloud_connector_id: Id of the cloud connector
    :param Sequence[Union['GetRuleRdsDependArgs', 'GetRuleRdsDependArgsDict']] depends: Dependent rules
    :param _builtins.int idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
    :param _builtins.str name: Name of the rule
    :param Sequence[Union['GetRuleRdsTcpArgs', 'GetRuleRdsTcpArgsDict']] tcps: TCP routing configuration
    """
    __args__ = dict()
    __args__['cloudConnectorId'] = cloud_connector_id
    __args__['database'] = database
    __args__['depends'] = depends
    __args__['idleTimeMins'] = idle_time_mins
    __args__['name'] = name
    __args__['tcps'] = tcps
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:autostopping/getRuleRds:getRuleRds', __args__, opts=opts, typ=GetRuleRdsResult)
    return __ret__.apply(lambda __response__: GetRuleRdsResult(
        cloud_connector_id=pulumi.get(__response__, 'cloud_connector_id'),
        database=pulumi.get(__response__, 'database'),
        depends=pulumi.get(__response__, 'depends'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        idle_time_mins=pulumi.get(__response__, 'idle_time_mins'),
        name=pulumi.get(__response__, 'name'),
        tcps=pulumi.get(__response__, 'tcps')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VariablesArgs', 'Variables']

@pulumi.input_type
class VariablesArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 spec: pulumi.Input['VariablesSpecArgs'],
                 type: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Variables resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input['VariablesSpecArgs'] spec: List of Spec Fields.
        :param pulumi.Input[_builtins.str] type: Type of Variable
        :param pulumi.Input[_builtins.str] description: Description of the entity
        :param pulumi.Input[_builtins.str] name: Name of the Variable
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "spec", spec)
        pulumi.set(__self__, "type", type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> pulumi.Input['VariablesSpecArgs']:
        """
        List of Spec Fields.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: pulumi.Input['VariablesSpecArgs']):
        pulumi.set(self, "spec", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of Variable
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the entity
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Variable
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)


@pulumi.input_type
class _VariablesState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input['VariablesSpecArgs']] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Variables resources.
        :param pulumi.Input[_builtins.str] description: Description of the entity
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.str] name: Name of the Variable
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input['VariablesSpecArgs'] spec: List of Spec Fields.
        :param pulumi.Input[_builtins.str] type: Type of Variable
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the entity
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Variable
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['VariablesSpecArgs']]:
        """
        List of Spec Fields.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['VariablesSpecArgs']]):
        pulumi.set(self, "spec", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of Variable
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("harness:platform/variables:Variables")
class Variables(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input[Union['VariablesSpecArgs', 'VariablesSpecArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Variables.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.Variables("test",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            type="String",
            spec={
                "value_type": "FIXED",
                "fixed_value": "fixedValue",
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level variables

        ```sh
        $ pulumi import harness:platform/variables:Variables example <variable_id>
        ```

        Import org level variables

        ```sh
        $ pulumi import harness:platform/variables:Variables example <ord_id>/<variable_id>
        ```

        Import project level variables

        ```sh
        $ pulumi import harness:platform/variables:Variables example <org_id>/<project_id>/<variable_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the entity
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.str] name: Name of the Variable
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[Union['VariablesSpecArgs', 'VariablesSpecArgsDict']] spec: List of Spec Fields.
        :param pulumi.Input[_builtins.str] type: Type of Variable
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VariablesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Variables.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.Variables("test",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            type="String",
            spec={
                "value_type": "FIXED",
                "fixed_value": "fixedValue",
            })
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level variables

        ```sh
        $ pulumi import harness:platform/variables:Variables example <variable_id>
        ```

        Import org level variables

        ```sh
        $ pulumi import harness:platform/variables:Variables example <ord_id>/<variable_id>
        ```

        Import project level variables

        ```sh
        $ pulumi import harness:platform/variables:Variables example <org_id>/<project_id>/<variable_id>
        ```

        :param str resource_name: The name of the resource.
        :param VariablesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VariablesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 spec: Optional[pulumi.Input[Union['VariablesSpecArgs', 'VariablesSpecArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VariablesArgs.__new__(VariablesArgs)

            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if spec is None and not opts.urn:
                raise TypeError("Missing required property 'spec'")
            __props__.__dict__["spec"] = spec
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(Variables, __self__).__init__(
            'harness:platform/variables:Variables',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            spec: Optional[pulumi.Input[Union['VariablesSpecArgs', 'VariablesSpecArgsDict']]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Variables':
        """
        Get an existing Variables resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the entity
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.str] name: Name of the Variable
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: Project Identifier for the Entity
        :param pulumi.Input[Union['VariablesSpecArgs', 'VariablesSpecArgsDict']] spec: List of Spec Fields.
        :param pulumi.Input[_builtins.str] type: Type of Variable
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VariablesState.__new__(_VariablesState)

        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["spec"] = spec
        __props__.__dict__["type"] = type
        return Variables(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the entity
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Variable
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Organization Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def spec(self) -> pulumi.Output['outputs.VariablesSpec']:
        """
        List of Spec Fields.
        """
        return pulumi.get(self, "spec")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of Variable
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCentralNotificationChannelResult',
    'AwaitableGetCentralNotificationChannelResult',
    'get_central_notification_channel',
    'get_central_notification_channel_output',
]

@pulumi.output_type
class GetCentralNotificationChannelResult:
    """
    A collection of values returned by getCentralNotificationChannel.
    """
    def __init__(__self__, account=None, channels=None, created=None, id=None, identifier=None, last_modified=None, name=None, notification_channel_type=None, org=None, org_id=None, project=None, project_id=None, status=None):
        if account and not isinstance(account, str):
            raise TypeError("Expected argument 'account' to be a str")
        pulumi.set(__self__, "account", account)
        if channels and not isinstance(channels, list):
            raise TypeError("Expected argument 'channels' to be a list")
        pulumi.set(__self__, "channels", channels)
        if created and not isinstance(created, int):
            raise TypeError("Expected argument 'created' to be a int")
        pulumi.set(__self__, "created", created)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if last_modified and not isinstance(last_modified, int):
            raise TypeError("Expected argument 'last_modified' to be a int")
        pulumi.set(__self__, "last_modified", last_modified)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if notification_channel_type and not isinstance(notification_channel_type, str):
            raise TypeError("Expected argument 'notification_channel_type' to be a str")
        pulumi.set(__self__, "notification_channel_type", notification_channel_type)
        if org and not isinstance(org, str):
            raise TypeError("Expected argument 'org' to be a str")
        pulumi.set(__self__, "org", org)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def account(self) -> Optional[_builtins.str]:
        """
        Account identifier associated with this notification channel.
        """
        return pulumi.get(self, "account")

    @_builtins.property
    @pulumi.getter
    def channels(self) -> Optional[Sequence['outputs.GetCentralNotificationChannelChannelResult']]:
        """
        Configuration details of the notification channel.
        """
        return pulumi.get(self, "channels")

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[_builtins.int]:
        """
        Timestamp when the notification channel was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the notification channel.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="lastModified")
    def last_modified(self) -> Optional[_builtins.int]:
        """
        Timestamp when the notification channel was last modified.
        """
        return pulumi.get(self, "last_modified")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the notification channel.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationChannelType")
    def notification_channel_type(self) -> Optional[_builtins.str]:
        """
        Type of notification channel. One of: EMAIL, SLACK, PAGERDUTY, MSTeams, WEBHOOK, DATADOG.
        """
        return pulumi.get(self, "notification_channel_type")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'org_id' instead.""")
    def org(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization. Use `org_id` instead.
        """
        return pulumi.get(self, "org")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release. Please use 'project_id' instead.""")
    def project(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project. Use `project_id` instead.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        Status of the notification channel. Possible values are ENABLED or DISABLED.
        """
        return pulumi.get(self, "status")


class AwaitableGetCentralNotificationChannelResult(GetCentralNotificationChannelResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCentralNotificationChannelResult(
            account=self.account,
            channels=self.channels,
            created=self.created,
            id=self.id,
            identifier=self.identifier,
            last_modified=self.last_modified,
            name=self.name,
            notification_channel_type=self.notification_channel_type,
            org=self.org,
            org_id=self.org_id,
            project=self.project,
            project_id=self.project_id,
            status=self.status)


def get_central_notification_channel(account: Optional[_builtins.str] = None,
                                     channels: Optional[Sequence[Union['GetCentralNotificationChannelChannelArgs', 'GetCentralNotificationChannelChannelArgsDict']]] = None,
                                     created: Optional[_builtins.int] = None,
                                     identifier: Optional[_builtins.str] = None,
                                     last_modified: Optional[_builtins.int] = None,
                                     name: Optional[_builtins.str] = None,
                                     notification_channel_type: Optional[_builtins.str] = None,
                                     org: Optional[_builtins.str] = None,
                                     org_id: Optional[_builtins.str] = None,
                                     project: Optional[_builtins.str] = None,
                                     project_id: Optional[_builtins.str] = None,
                                     status: Optional[_builtins.str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCentralNotificationChannelResult:
    """
    Data source for retrieving a central notification channel in Harness.


    :param _builtins.str account: Account identifier associated with this notification channel.
    :param Sequence[Union['GetCentralNotificationChannelChannelArgs', 'GetCentralNotificationChannelChannelArgsDict']] channels: Configuration details of the notification channel.
    :param _builtins.int created: Timestamp when the notification channel was created.
    :param _builtins.str identifier: Unique identifier of the notification channel.
    :param _builtins.int last_modified: Timestamp when the notification channel was last modified.
    :param _builtins.str name: Name of the notification channel.
    :param _builtins.str notification_channel_type: Type of notification channel. One of: EMAIL, SLACK, PAGERDUTY, MSTeams, WEBHOOK, DATADOG.
    :param _builtins.str org: Unique identifier of the organization. Use `org_id` instead.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project: Unique identifier of the project. Use `project_id` instead.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str status: Status of the notification channel. Possible values are ENABLED or DISABLED.
    """
    __args__ = dict()
    __args__['account'] = account
    __args__['channels'] = channels
    __args__['created'] = created
    __args__['identifier'] = identifier
    __args__['lastModified'] = last_modified
    __args__['name'] = name
    __args__['notificationChannelType'] = notification_channel_type
    __args__['org'] = org
    __args__['orgId'] = org_id
    __args__['project'] = project
    __args__['projectId'] = project_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getCentralNotificationChannel:getCentralNotificationChannel', __args__, opts=opts, typ=GetCentralNotificationChannelResult).value

    return AwaitableGetCentralNotificationChannelResult(
        account=pulumi.get(__ret__, 'account'),
        channels=pulumi.get(__ret__, 'channels'),
        created=pulumi.get(__ret__, 'created'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        last_modified=pulumi.get(__ret__, 'last_modified'),
        name=pulumi.get(__ret__, 'name'),
        notification_channel_type=pulumi.get(__ret__, 'notification_channel_type'),
        org=pulumi.get(__ret__, 'org'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project=pulumi.get(__ret__, 'project'),
        project_id=pulumi.get(__ret__, 'project_id'),
        status=pulumi.get(__ret__, 'status'))
def get_central_notification_channel_output(account: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            channels: Optional[pulumi.Input[Optional[Sequence[Union['GetCentralNotificationChannelChannelArgs', 'GetCentralNotificationChannelChannelArgsDict']]]]] = None,
                                            created: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                            identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                            last_modified: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                            name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            notification_channel_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            org: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            project: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            status: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCentralNotificationChannelResult]:
    """
    Data source for retrieving a central notification channel in Harness.


    :param _builtins.str account: Account identifier associated with this notification channel.
    :param Sequence[Union['GetCentralNotificationChannelChannelArgs', 'GetCentralNotificationChannelChannelArgsDict']] channels: Configuration details of the notification channel.
    :param _builtins.int created: Timestamp when the notification channel was created.
    :param _builtins.str identifier: Unique identifier of the notification channel.
    :param _builtins.int last_modified: Timestamp when the notification channel was last modified.
    :param _builtins.str name: Name of the notification channel.
    :param _builtins.str notification_channel_type: Type of notification channel. One of: EMAIL, SLACK, PAGERDUTY, MSTeams, WEBHOOK, DATADOG.
    :param _builtins.str org: Unique identifier of the organization. Use `org_id` instead.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project: Unique identifier of the project. Use `project_id` instead.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str status: Status of the notification channel. Possible values are ENABLED or DISABLED.
    """
    __args__ = dict()
    __args__['account'] = account
    __args__['channels'] = channels
    __args__['created'] = created
    __args__['identifier'] = identifier
    __args__['lastModified'] = last_modified
    __args__['name'] = name
    __args__['notificationChannelType'] = notification_channel_type
    __args__['org'] = org
    __args__['orgId'] = org_id
    __args__['project'] = project
    __args__['projectId'] = project_id
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getCentralNotificationChannel:getCentralNotificationChannel', __args__, opts=opts, typ=GetCentralNotificationChannelResult)
    return __ret__.apply(lambda __response__: GetCentralNotificationChannelResult(
        account=pulumi.get(__response__, 'account'),
        channels=pulumi.get(__response__, 'channels'),
        created=pulumi.get(__response__, 'created'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        last_modified=pulumi.get(__response__, 'last_modified'),
        name=pulumi.get(__response__, 'name'),
        notification_channel_type=pulumi.get(__response__, 'notification_channel_type'),
        org=pulumi.get(__response__, 'org'),
        org_id=pulumi.get(__response__, 'org_id'),
        project=pulumi.get(__response__, 'project'),
        project_id=pulumi.get(__response__, 'project_id'),
        status=pulumi.get(__response__, 'status')))
